-----------------------------------------------------------------------------

if not AceLibrary:HasInstance("FuBarPlugin-2.0") then return end

-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AssessmentFu")

L:RegisterTranslations("enUS", function() return {
	["Assessment"] = true,
    ["Fubar Options"] = true,
    ["FuBar options."] = true,
	["Click to toggle visible windows."] = "|cffeda55fClick|r to toggle visible windows.",
	["Alt-Click to reset fight data."] = "|cffeda55fAlt-Click|r to reset fight data.",
	["Ctrl-Alt-Click to reset all fight data."] = "|cffeda55fCtrl-Alt-Click|r to reset all fight data.",
	["Shift-Click to open configuration."] = "|cffeda55fShift-Click|r to open configuration.",

	["FuBar Text"] = true,
	["Choose what to show on FuBar"] = true,
	["Update Interval"] = true,
	["Time in seconds before updating FuBar text."] = true,
	["Text"] = true,
	["Select what text to display."] = true,
	["None"] = true,

	["Advanced Options"] = true,
	["Options for advanced users."] = true,

	["Text Tag"] = true,
	["FuBar Text Tag."] = true,
	["Any Tag String."] = true,

	["Fight Data"] = true,
	["Select which fight data to use for tag display."] = true,
	["Total Data"] = true,
	["Current Fight"] = true,
	["Previous Fight"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Assessment"] = "Assessment",
	["Fubar Options"] = "FuBar 설정",
	["FuBar options."] = "FuBar 설정입니다.",
	["Click to toggle visible windows."] = "창 표시를 전환하려면 |cffeda55f클릭|r하세요.",
	["Alt-Click to reset fight data."] = "전투 데이터를 초기화하려면 |cffeda55fALT-클릭|r하세요.",
	["Ctrl-Alt-Click to reset all fight data."] = "모든 전투 데이터를 초기화 하려면 |cffeda55fCTRL-ALT-클릭|r하세요.",
	["Shift-Click to open configuration."] = "환경 설정을 열려면 |cffeda55fSHIFT-클릭|r하세요.",

	["FuBar Text"] = "FuBar 글자",
	["Choose what to show on FuBar"] = "FuBar에 표시할 정보를 선택합니다.",
	["Update Interval"] = "갱신 간격",
	["Time in seconds before updating FuBar text."] = "FuBar 글자를 갱신할 시간 간격입니다.",
	["Text"] = "글자",
	["Select what text to display."] = "표시할 글자를 선택하세요.",
	["None"] = "없음",

	["Advanced Options"] = "고급 설정",
	["Options for advanced users."] = "고급 사용자를 위한 설정입니다.",

	["Text Tag"] = "글자 태그",
	["FuBar Text Tag."] = "FuBar 텍스트 태그입니다.",
	["Any Tag String."] = "태그 문자열입니다.",

	["Fight Data"] = "전투 데이터",
	["Select which fight data to use for tag display."] = "태그 표시를 사용할 전투 데이터를 선택하세요.",
	["Total Data"] = "총 데이터",
	["Current Fight"] = "현재 전투",
	["Previous Fight"] = "이전 전투",
} end)

-----------------------------------------------------------------------------

local AssessmentFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceEvent-2.0", "AceDB-2.0")
AssessmentFu:RegisterDB("AssessmentFuDB")
AssessmentFu.title = "Assessment"
AssessmentFu.name = "FuBar - Assessment"
AssessmentFu.hasIcon = "Interface\\Icons\\INV_Misc_StoneTablet_01.jpg"	-- Placeholder
AssessmentFu.blizzardTooltip = true
AssessmentFu.defaultPosition = 'LEFT'
AssessmentFu.hideWithoutStandby = true
AssessmentFu.independentProfile = true
AssessmentFu.hasNoColor = true
 
-----------------------------------------------------------------------------

local tagData =
{
	key = UnitName("player")
}
local textMethod

-----------------------------------------------------------------------------

AssessmentFu:RegisterDefaults('profile', 
	{
		updateInterval = 0.5,
		fightIndex = 1,
		textTag	= "Assessment",
	}
)

AssessmentFu.OnMenuRequest = Assessment.Options

local fuBarArgs = AceLibrary("FuBarPlugin-2.0"):GetAceOptionsDataTable(AssessmentFu)
if not AssessmentFu.OnMenuRequest.args.fubar then
	AssessmentFu.OnMenuRequest.args.extrasSpacer =
	{
		type = 'header',
		order = 70,
	}
	
	AssessmentFu.OnMenuRequest.args.fubar = 
	{
		type = "group",
		name = L["Fubar Options"],
		desc = L["FuBar options."],
		args = fuBarArgs,
		order = 80,
	}
end

fuBarArgs.text =
{
	type = "group",
	name = L["FuBar Text"],
	desc = L["Choose what to show on FuBar"],
	args = 
	{
		updateRate =
		{
			type	= "range",
			name	= L["Update Interval"],
			desc	= L["Time in seconds before updating FuBar text."],
			min		= 0.05,
			max		= 2,
			step	= 0.05,
			get		= function() return AssessmentFu.db.profile.updateInterval end,
			set		= function(v) AssessmentFu.db.profile.updateInterval = v AssessmentFu:ScheduleRepeatingEvent("AssessmentFu:Update", AssessmentFu.Update, v, AssessmentFu) end,
			order	= 1
		},
		text =
		{
			type = "text",
			name = L["Text"],
			desc = L["Select what text to display."],
			get = function() return AssessmentFu:GetTextOption() end,
			set = function(v) AssessmentFu:SetTextOption(v) end,
			validate = { None = L["None"] },
		},

		advanced =
		{
			type = "group",
			name = L["Advanced Options"],
			desc = L["Options for advanced users."],
			order = -1,
			args =
			{
				textTag =
				{
					type	= "text",
					name	= L["Text Tag"],
					desc	= L["FuBar Text Tag."],
					get		= function() return Assessment:HighlightTagSyntax(AssessmentFu.db.profile.textTag, "string") end,
					set		= function(v) AssessmentFu:SetTextTag(v) end,
					usage	= L["Any Tag String."],
					order	= 2,
				},

				fightData =
				{
					type = "text",
					name = L["Fight Data"],
					desc = L["Select which fight data to use for tag display."],
					get  = function() return tostring(AssessmentFu.db.profile.fightIndex) end,
					set	 = function(v) AssessmentFu.db.profile.fightIndex = tonumber(v) AssessmentFu:UpdateText() end,
					validate = { ["0"] = L["Total Data"], ["1"] = L["Current Fight"], ["2"] = L["Previous Fight"] },
				}
			}
		},
	}
}

-----------------------------------------------------------------------------

function AssessmentFu:OnEnable()
	textMethod = Assessment:CompileTag(self.db.profile.textTag, "string").method
	self:ScheduleRepeatingEvent("AssessmentFu:Update", self.Update, self.db.profile.updateInterval, self)
end

function AssessmentFu:Update()
	self:UpdateText()
end

function AssessmentFu:OnInitialize()
	for k,v in pairs(Assessment.DefaultTags) do
		fuBarArgs.text.args.text.validate[k] = v.description
	end
end

local lastText
function AssessmentFu:OnTextUpdate()
	tagData.fightData = Assessment:GetFightData(self.db.profile.fightIndex)
	local text = textMethod(tagData)
	if text ~= lastText then
		lastText = text
		self:SetText(text)
	end
end

function AssessmentFu:OnTooltipUpdate()
	GameTooltip:AddLine(L["Assessment"])
	GameTooltip:AddLine(" ")
	
	GameTooltip:AddLine(L["Click to toggle visible windows."], 0.2, 1, 0.2)
	GameTooltip:AddLine(L["Alt-Click to reset fight data."], 0.2, 1, 0.2)
	GameTooltip:AddLine(L["Ctrl-Alt-Click to reset all fight data."], 0.2, 1, 0.2)

	if Assessment.Options.args.waterfall then
		GameTooltip:AddLine(L["Shift-Click to open configuration."], 0.2, 1, 0.2)
	end
end

local visibleResultTable = { }
function AssessmentFu:OnClick()
	if Assessment.Options.args.waterfall and IsShiftKeyDown() then
		GameTooltip:Hide()
		Assessment.Options.args.waterfall.func()
		return
	end

	if IsAltKeyDown() then
		if IsControlKeyDown() then
			Assessment:ResetFightData()
		else
			Assessment:ResetUnnamedFightData()
		end
	else
		visibleResultTable.result = false
		self:TriggerEvent("Assessment:TestVisible", visibleResultTable)
		if visibleResultTable.result then
			self:TriggerEvent("Assessment:HideAll")
		else
			self:TriggerEvent("Assessment:ShowAll")
		end
	end
	


	self:UpdateTooltip()
end

function AssessmentFu:GetTextOption()
	local tag = self.db.profile.textTag
	local fightIndex = self.db.profile.fightIndex
	if tag == "Assessment" then return "None" end

	for k,v in pairs(Assessment.DefaultTags) do
		if fightIndex == v.fightIndex and tag == "Assessment: "..v.tag then
			return k
		end
	end
	
	return ""
end

function AssessmentFu:SetTextTag(v)
	v = Assessment:FixTagCasing(v, "string")
	self.db.profile.textTag = v
	textMethod = Assessment:CompileTag(v, "string").method 
	self:UpdateText()
end

function AssessmentFu:SetTextOption(v)
	if v == "None" then
		self:SetTextTag("Assessment")
	else
		local tagData = Assessment.DefaultTags[v]
		self.db.profile.fightIndex = tagData.fightIndex
		self:SetTextTag("Assessment: "..tagData.tag)
	end
end

-----------------------------------------------------------------------------
